#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.


; Version of Toby Doom, change for latest version when released
tobyDoomVersion := "7-0"
deathMapVersion := "1-0"

; Functions
CheckForFile(fileName) {
    ; Returns if file exists or not
    if (FileExist(fileName)) {
        return true
    } else {
        return false
    }
}


; Extract the major version number for addon loading
versionParts := StrSplit(tobyDoomVersion, "-")
addonVersion := versionParts[1]


; Construct basic launch command for all options
addonsFolder := ".\Addons\"
FilePattern := "TobyV" . addonVersion . "_*.pk3"
addons := ""
Loop, Files, % addonsFolder . FilePattern, R
{
    addons .= " """ . A_LoopFilePath . """"
}
launchCommand := "gzdoom.exe -config TobyConfig.ini -file TobyAccMod_V" . tobyDoomVersion . ".pk3" . addons

mapList := ["Com Station (2-4 players)"
          , "Warehouse (2-4 players)"
          , "Sector 3 (2-4 players)"
          , "Dungeon of Doom (2-4 players)"
          , "Ocean Fortress (2-4 players)"
          , "Water Treatment Facility (2-4 players)"
          , "Phobos Base Site 4 (2-4 players)"
          , "Hangar Bay 18 (2-4 players)"]

if (!CheckForFile("freedoom2.wad") && !CheckForFile("doom2.wad")) {
    ; No wads found.
    MsgBox, No Doom WADs detected. Your browser will now open so you can download the Freedoom WADs. Please extract the downloaded ZIP files and place the .WAD files in this directory.
    Run, % "https://freedoom.github.io/download.html"
    ExitApp
}
Menu, MyMenu, Add, Play Classic Doom Games, PlayClassicDoomGames
Menu, MyMenu, Add, Host Co-op Play Classic Doom Games, coOpPlayClassicDoomGames
Menu, MyMenu, Add, Play Toby Doom, PlayTobyDoom
Menu, MyMenu, Add, Host Co-op Play Toby Doom, CoOpPlayTobyDoom
if (CheckForFile("OpMDK.wad")) {
    Menu, MyMenu, Add, Play Operation MDK, PlayOperationMDK
    Menu, MyMenu, Add, Host Co-op Play Operation MDK, CoOpPlayOperationMDK
}
else {
    Menu, MyMenu, Add, Download Operation MDK, DownloadOperationMDK
}
Menu, MyMenu, Add, Join Co-op, JoinCoOp
Menu, MyMenu, Add, Host Death Match, HostMatch
Menu, MyMenu, Add, Join Death Match, JoinMatch
Menu, MyMenu, Show

Return

PlayClassicDoomGames:
    Run, % launchCommand
return

CoOpPlayClassicDoomGames:
    InputBox, Players, Host Co-op, Enter Number of Players:, , 200, 150
    If ErrorLevel
        Return
    Run, % launchCommand . " -host " . Players . "+set sv_cheats 1 +set sv_weaponsstay 1 +set sv_respawnprotect 1 +set sv_respawnsuper 1 +set alwaysapplydmflags 1 -extratic -dup 3"
return

PlayTobyDoom:
    Run, % launchCommand . " TobyDoomLevels.wad"
return

CoOpPlayTobyDoom:
    InputBox, Players, Host Co-op, Enter Number of Players:, , 200, 150
    If ErrorLevel
        Return
    Run, % launchCommand . " TobyDoomLevels.wad -host " . Players . "+set sv_cheats 1 +set sv_weaponsstay 1 +set sv_respawnprotect 1 +set sv_respawnsuper 1 +set alwaysapplydmflags 1 -extratic -dup 3"
return

PlayOperationMDK:
    Run, % launchCommand . " OpMDK.wad"
return

CoOpPlayOperationMDK:
    InputBox, Players, Host Co-op, Enter Number of Players:, , 200, 150
    If ErrorLevel
        Return
    Run, % launchCommand . " OpMDK.wad  -host " . Players . "+set sv_cheats 1 +set sv_weaponsstay 1 +set sv_respawnprotect 1 +set sv_respawnsuper 1 +set alwaysapplydmflags 1 -extratic -dup 3"
return

DownloadOperationMDK:
    currentDir := A_ScriptDir
    SplitPath, currentDir, dirName
    MsgBox, Your browser will now open so that you can download Operation MDK. Please extract the zip file to the %dirName% directory.
    Run, % "https://drive.google.com/file/d/1lbPZM2CAhr86jsFncNtBNFIpxIV3HB1u/view?usp=sharing"
    ExitApp
return

HostMatch:
    MsgBox, Welcome to multiplayer setup. If you would like to add a bot, set players to 1. When the game starts, press the ` key, type add bot and press enter. Repeat add bot for each bot you want to add, and when done press the ` key again.
    ; Create and display map menu
    Menu, MapMenu, Add, Com Station (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Warehouse (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Sector 3 (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Dungeon of Doom (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Ocean Fortress (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Water Treatment Facility (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Phobos Base Site 4 (2-4 players), MapMenuHandler
    Menu, MapMenu, Add, Hangar Bay 18 (2-4 players), MapMenuHandler
    Menu, MapMenu, Show
Return

MapMenuHandler:
    mapIndex := A_ThisMenuItemPos  ; Get the position of the selected item in the menu
    
    ; Ask for number of players and frag limit
    InputBox, Players, Host Death Match, Enter Number of Players:, , 200, 150
    If ErrorLevel
        Return
    InputBox, Frags, Host Death Match, Enter Frag Limit:, 20, 200, 150
    If ErrorLevel
        Return
    
    Run, % launchCommand . " TobyDeathArena_V" . deathMapVersion . ".wad -host " . Players . " -deathmatch +fraglimit " . Frags . " +set sv_cheats 1 +dmflags 16384 +dmflags 4 +dmflags 128 +dmflags 4096 -extratic -dup 3 -warp " . mapIndex
Return

JoinCoOp:
    InputBox, IPAddress, Join Co-op, Enter IP Address:, , 200, 150
    If ErrorLevel
        Return
    Run, % launchCommand . "-join " . IPAddress
Return

JoinMatch:
    InputBox, IPAddress, Join Death Match, Enter IP Address:, , 200, 150
    If ErrorLevel
        Return
    Run, % launchCommand . " TobyDeathArena_V" . deathMapVersion . ".wad -join " . IPAddress
Return

ExitApp

